GetItBootstrapper class abstract

Inheritance
  • Object
  • PrismBootstrapper
  • GetItBootstrapper

Constructors

GetItBootstrapper()

Properties

catalog ↔ ModuleCatalog
getter/setter pairinherited
container → GetIt
no setter
hashCode int
The hash code for this object.
no setterinherited
modules List<Module>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureContainer(Object container) → void
override
createContainer() Object
override
createModuleCatalog() → ModuleCatalog
inherited
createModules(Object container) → void
inherited
initModules(Object container) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited