GetItModule class abstract

Inheritance
  • Object
  • Module<GetIt>
  • GetItModule

Constructors

GetItModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(GetIt container) Future<void>
Initializes a module
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset(GetIt container) Future<void>
Resets a module and prepare it for another initialization call Can be used to reset state after a user log out for instance.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited